@@ -53,9 +53,13 @@ from celery.worker import state
 def apply_batches_task(task, args, loglevel, logfile):
     task.request.update({"loglevel": loglevel, "logfile": logfile})
     try:
-        return task(*args)
+        result = task(*args)
+    except Exception, exp:
+        result = None
+        task.logger.error("There was an Exception: %s" % exp)
     finally:
         task.request.clear()
+    return result
 
 
 class SimpleRequest(object):
@@ -160,7 +164,7 @@ class Batches(Task):
         return self._pool.apply_async(apply_batches_task,
                     (self, args, loglevel, logfile),
                     accept_callback=on_accepted,
-                    callbacks=acks_late[True] and [on_return] or [])
+                    callback=acks_late[True] and on_return or None)
 
     def debug(self, msg):
         self.logger.debug("%s: %s" % (self.name, msg))
