@@ -8,13 +8,15 @@ Custom data structures.
 :license: BSD, see LICENSE for more details.
 
 """
-from __future__ import generators
+from __future__ import absolute_import
+from __future__ import with_statement
 
 import time
 import traceback
 
 from itertools import chain
 from Queue import Empty
+from threading import RLock
 
 from celery.utils.compat import OrderedDict
 
@@ -95,14 +97,14 @@ class ConfigurationView(AttributeDictMixin):
     """
     changes = None
     defaults = None
+    _order = None
 
     def __init__(self, changes, defaults):
-        self.__dict__["changes"] = changes
-        self.__dict__["defaults"] = defaults
-        self.__dict__["_order"] = [changes] + defaults
+        self.__dict__.update(changes=changes, defaults=defaults,
+                             _order=[changes] + defaults)
 
     def __getitem__(self, key):
-        for d in self.__dict__["_order"]:
+        for d in self._order:
             try:
                 return d[key]
             except KeyError:
@@ -110,7 +112,7 @@ class ConfigurationView(AttributeDictMixin):
         raise KeyError(key)
 
     def __setitem__(self, key, value):
-        self.__dict__["changes"][key] = value
+        self.changes[key] = value
 
     def get(self, key, default=None):
         try:
@@ -126,10 +128,10 @@ class ConfigurationView(AttributeDictMixin):
             return default
 
     def update(self, *args, **kwargs):
-        return self.__dict__["changes"].update(*args, **kwargs)
+        return self.changes.update(*args, **kwargs)
 
     def __contains__(self, key):
-        for d in self.__dict__["_order"]:
+        for d in self._order:
             if key in d:
                 return True
         return False
@@ -143,7 +145,7 @@ class ConfigurationView(AttributeDictMixin):
     def _iter(self, op):
         # defaults must be first in the stream, so values in
         # changes takes precedence.
-        return chain(*[op(d) for d in reversed(self.__dict__["_order"])])
+        return chain(*[op(d) for d in reversed(self._order)])
 
     def iterkeys(self):
         return self._iter(lambda d: d.iterkeys())
@@ -206,9 +208,10 @@ def consume_queue(queue):
         []
 
     """
+    get = queue.get_nowait
     while 1:
         try:
-            yield queue.get_nowait()
+            yield get()
         except Empty:
             break
 
@@ -225,6 +228,7 @@ class LimitedSet(object):
     :keyword expires: Time in seconds, before a membership expires.
 
     """
+    __slots__ = ("maxlen", "expires", "_data")
 
     def __init__(self, maxlen=None, expires=None):
         self.maxlen = maxlen
@@ -297,11 +301,17 @@ class LocalCache(OrderedDict):
     def __init__(self, limit=None):
         super(LocalCache, self).__init__()
         self.limit = limit
+        self.lock = RLock()
 
     def __setitem__(self, key, value):
-        while len(self) >= self.limit:
-            self.popitem(last=False)
-        super(LocalCache, self).__setitem__(key, value)
+        with self.lock:
+            while len(self) >= self.limit:
+                self.popitem(last=False)
+            super(LocalCache, self).__setitem__(key, value)
+
+    def pop(self, key, *args):
+        with self.lock:
+            super(LocalCache, self).pop(key, *args)
 
 
 class TokenBucket(object):
