@@ -1,14 +1,14 @@
+from collections import defaultdict
+
 from sqlalchemy import create_engine
 from sqlalchemy.orm import sessionmaker
 from sqlalchemy.ext.declarative import declarative_base
 
-from celery import conf
-from celery.utils.compat import defaultdict
-
 ResultModelBase = declarative_base()
 
 _SETUP = defaultdict(lambda: False)
 _ENGINES = {}
+_MAKERS = {}
 
 
 def get_engine(dburi, **kwargs):
@@ -19,7 +19,9 @@ def get_engine(dburi, **kwargs):
 
 def create_session(dburi, **kwargs):
     engine = get_engine(dburi, **kwargs)
-    return engine, sessionmaker(bind=engine)
+    if dburi not in _MAKERS:
+        _MAKERS[dburi] = sessionmaker(bind=engine)
+    return engine, _MAKERS[dburi]
 
 
 def setup_results(engine):
@@ -28,7 +30,7 @@ def setup_results(engine):
         _SETUP["results"] = True
 
 
-def ResultSession(dburi=conf.RESULT_DBURI, **kwargs):
+def ResultSession(dburi, **kwargs):
     engine, session = create_session(dburi, **kwargs)
     setup_results(engine)
     return session()
