@@ -1,36 +1,39 @@
-from celery.utils import timer2
+import atexit
 
-from celery import conf
-from celery import log
+from celery import platforms
+from celery.app import app_or_default
 from celery.datastructures import TokenBucket
-from celery.events import EventReceiver
-from celery.events.state import State
-from celery.messaging import establish_connection
-from celery.utils import instantiate
+from celery.utils import timer2
+from celery.utils import instantiate, LOG_LEVELS
 from celery.utils.dispatch import Signal
 from celery.utils.timeutils import rate
 
 
 class Polaroid(object):
+    timer = timer2
     shutter_signal = Signal(providing_args=("state", ))
     cleanup_signal = Signal()
     clear_after = False
 
     _tref = None
+    _ctref = None
 
     def __init__(self, state, freq=1.0, maxrate=None,
-            cleanup_freq=3600.0, logger=None):
+            cleanup_freq=3600.0, logger=None, timer=None, app=None):
+        self.app = app_or_default(app)
         self.state = state
         self.freq = freq
         self.cleanup_freq = cleanup_freq
-        self.logger = logger or log.get_default_logger(name="celery.cam")
+        self.timer = timer or self.timer
+        self.logger = logger or \
+                self.app.log.get_default_logger(name="celery.cam")
         self.maxrate = maxrate and TokenBucket(rate(maxrate))
 
     def install(self):
-        self._tref = timer2.apply_interval(self.freq * 1000.0,
-                                           self.capture)
-        self._ctref = timer2.apply_interval(self.cleanup_freq * 1000.0,
-                                            self.cleanup)
+        self._tref = self.timer.apply_interval(self.freq * 1000.0,
+                                               self.capture)
+        self._ctref = self.timer.apply_interval(self.cleanup_freq * 1000.0,
+                                                self.cleanup)
 
     def on_shutter(self, state):
         pass
@@ -39,17 +42,13 @@ class Polaroid(object):
         pass
 
     def cleanup(self):
-        self.debug("Cleanup: Running...")
+        self.logger.debug("Cleanup: Running...")
         self.cleanup_signal.send(None)
         self.on_cleanup()
 
-    def debug(self, msg):
-        if self.logger:
-            self.logger.debug(msg)
-
     def shutter(self):
         if self.maxrate is None or self.maxrate.can_consume():
-            self.debug("Shutter: %s" % (self.state, ))
+            self.logger.debug("Shutter: %s" % (self.state, ))
             self.shutter_signal.send(self.state)
             self.on_shutter(self.state)
 
@@ -58,7 +57,7 @@ class Polaroid(object):
 
     def cancel(self):
         if self._tref:
-            self._tref()
+            self._tref()  # flush all received events.
             self._tref.cancel()
         if self._ctref:
             self._ctref.cancel()
@@ -72,21 +71,29 @@ class Polaroid(object):
 
 
 def evcam(camera, freq=1.0, maxrate=None, loglevel=0,
-        logfile=None):
+        logfile=None, pidfile=None, timer=None, app=None):
+    app = app_or_default(app)
+
+    if pidfile:
+        pidlock = platforms.create_pidlock(pidfile).acquire()
+        atexit.register(pidlock.release)
+
     if not isinstance(loglevel, int):
-        loglevel = conf.LOG_LEVELS[loglevel.upper()]
-    logger = log.setup_logger(loglevel=loglevel,
-                              logfile=logfile,
-                              name="celery.evcam")
+        loglevel = LOG_LEVELS[loglevel.upper()]
+    logger = app.log.setup_logger(loglevel=loglevel,
+                                  logfile=logfile,
+                                  name="celery.evcam")
+
     logger.info(
         "-> evcam: Taking snapshots with %s (every %s secs.)\n" % (
             camera, freq))
-    state = State()
-    cam = instantiate(camera, state,
-                      freq=freq, maxrate=maxrate, logger=logger)
+    state = app.events.State()
+    cam = instantiate(camera, state, app=app,
+                      freq=freq, maxrate=maxrate, logger=logger,
+                      timer=timer)
     cam.install()
-    conn = establish_connection()
-    recv = EventReceiver(conn, handlers={"*": state.event})
+    conn = app.broker_connection()
+    recv = app.events.Receiver(conn, handlers={"*": state.event})
     try:
         try:
             recv.capture(limit=None)
